<?php
namespace Controller;

use Zeedhi\Framework\DTO\Request;
use Traits\TResponse;
use Service\CustomizationFilesService;
use Util\Utilities;

class CustomizationFilesController
{
    protected $CustomizationFilesService;

    use TResponse;

   public function __construct(CustomizationFilesService $CustomizationFilesService)
   {
       $this->CustomizationFilesService = $CustomizationFilesService;
   }

   public function getPais()
   {
        try {
            $data = $this->CustomizationFilesService->getPais();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
   }

   public function getEstado(Request $request)
   {
        try {
            $params = $request->getParameters();
            $cdpais = array_key_exists('CDPAIS', $params) ? $params['CDPAIS'] : '';
            $data = $this->CustomizationFilesService->getEstado($cdpais);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
   }

   public function getMunicipio(Request $request)
   {
        try {
            $params = $request->getParameters();
            $sgestado = array_key_exists('SGESTADO', $params) ? $params['SGESTADO'] : '';
            $data = $this->CustomizationFilesService->getMunicipio($sgestado);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
   }

   public function getUseLicense()
   {
        try {
            $data = $this->CustomizationFilesService->getUseLicense();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
   }

   public function downloadPlanilhaPadrao()
   {
        $this->CustomizationFilesService->downloadPlanilhaPadrao();
   }

   public function validaArquivoPersonalizado(Request $request)
   {
       try {
           $file = $request->getParameter('FILE');
           $actions = $this->CustomizationFilesService->validaArquivoPersonalizado($file);
           $this->sendResponse($actions, 200);
       } catch (\Exception $ex) {
           $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
       }
   }
}