<?php

namespace Service;

use Factory\CustomizationFilesFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use Util\InstanceProvider;
use Util\Utilities;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Traits\TResponse;
use Service\BilletIssued;


class CustomizationFilesService
{
    use TResponse;

    protected $CustomizationFilesFactory;
    protected $EntityManager;
    protected $Environment;
    protected $newCode;
    protected $BilletIssued;
    protected $nrParc;

    public function __construct(CustomizationFilesFactory $CustomizationFilesFactory, Environment $Environment, NewCode $newCode, EntityManager $EntityManager, BilletIssued $BilletIssued)
    {
        $this->connection                   = $EntityManager->getConnection();
        $this->CustomizationFilesFactory    = $CustomizationFilesFactory;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
        $this->BilletIssued                 = $BilletIssued;
    }

    public function getPais()
    {
        return $this->CustomizationFilesFactory->getPais();
    }

    public function getEstado($cdpais)
    {
        return $this->CustomizationFilesFactory->getEstado($cdpais);
    }

    public function getMunicipio($sgestado)
    {
        return $this->CustomizationFilesFactory->getMunicipio($sgestado);
    }

    public function getUseLicense()
    {
        $cdCliente = Utilities::getEnvironment()->getCurrentCdCliente();
        return $this->CustomizationFilesFactory->getUseLicense($cdCliente);
    }

    public function downloadPlanilhaPadrao()
    {
        $url = Utilities::getPlanilhaPadraoFilePersonalization();
        $nomeArquivo = 'Planilha_Padrao';
        $tipo = 'xlsx';
        Utilities::downloadPlanilhaPadrao($url, $nomeArquivo, $tipo);
    }

    public function validaArquivoPersonalizado($file)
    {
        // A string codificada fornecida
        $encoded_data = $file[0]['b64File'];

        $data_start = strpos($encoded_data, ',') + 1;
        $encoded_data = substr($encoded_data, $data_start);
        $decoded_data = base64_decode($encoded_data);

        // Salve os dados em um arquivo temporário (opcional)
        $temp_file = tempnam(sys_get_temp_dir(), 'excel_');
        file_put_contents($temp_file, $decoded_data);

        $reader = \PHPExcel_IOFactory::createReaderForFile($temp_file);
        $spreadsheet = $reader->load($temp_file);

        // Obtenha a primeira planilha (você pode ajustar isso se houver várias planilhas)
        $worksheet = $spreadsheet->getActiveSheet();

        // Inicialize um array para armazenar os dados das linhas
        $data = [];

        // Itere pelas linhas com dados
        foreach ($worksheet->getRowIterator() as $row) {
            // Obtenha todas as células da linha
            $cellIterator = $row->getCellIterator();
            $cellIterator->setIterateOnlyExistingCells(false); // Inclui células vazias
            $rowData = [];

            // Itere pelas células da linha
            foreach ($cellIterator as $cell) {
                $rowData[] = $cell->getValue();
            }

            // Adicione os dados da linha ao array de dados
            $data[] = $rowData;
        }

        // Agora você tem todos os dados da planilha em formato de matriz

        // Inicialize um array para armazenar os dados válidos (sem linhas vazias)
        $validData = [];

        foreach ($data as $rowData) {
            // Verifique se pelo menos uma célula na linha possui um valor não vazio
            if (array_filter($rowData)) {
                // Adicione apenas linhas não vazias ao array de dados válidos
                $validData[] = $rowData;
            }
        }

        unlink($temp_file);

        // Agora, $validData contém apenas as linhas não vazias da planilha
        return $validData;
    }
}
