import { Utilities } from '@/util/Utilities';
import { LoadingService, Modal, ModalService, Select, TextInput } from '@zeedhi/common';
import { Config, Http, MemoryDatasource, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class CadastramentoAutomaticoPERController {
    public modalUploadArquivo!: Modal;

    public changeCampoSelect({ component }: any) {
        if (component.name === 'formLicencaUsoArqPersoform-IDTPIJURLUSO') {
            Metadata.getInstance<TextInput>('formLicencaUsoArqPersoform-NRINSJURLUSO').value = component.value;
        }
        if (component.name === 'formLicencaUsoArqPersoform-NMPAIS') {
            Metadata.getInstance<TextInput>('formLicencaUsoArqPersoform-CDPAIS').value = component.value;
            const UF = Metadata.getInstance<Select>('formLicencaUsoArqPersoform-UF');
            try {
                UF.datasource.setFilter({
                    CDPAIS: component.value,
                });
            } catch (e) {
                console.error(e);
            }
        }
        if (component.name === 'formLicencaUsoArqPersoform-UF') {
            Metadata.getInstance<TextInput>('formLicencaUsoArqPersoform-SGESTADO').value = component.value;
            const municipio = Metadata.getInstance<Select>('formLicencaUsoArqPersoform-NMMUNICIPIO');
            try {
                municipio.datasource.setFilter({
                    SGESTADO: component.value,
                });
            } catch (e) {
                console.error(e);
            }
        }
        if (component.name === 'formLicencaUsoArqPersoform-NMMUNICIPIO') {
            Metadata.getInstance<TextInput>('formLicencaUsoArqPersoform-CDMUNICIPIO').value = component.value;
        }
        if (component.name === 'formLicencaUsoArqPersoform-NMLINPCLIE') {
            Metadata.getInstance<TextInput>('formLicencaUsoArqPersoform-CDLINPCLIE').value = component.value.join('; ');
        }
    }

    public downloadPlanilhaPadrao() {
        window.open(`${Config.endPoint}/downloadPlanilhaPadrao`);
    }

    public async openModalUploadArquivo() {
        this.modalUploadArquivo = await ModalService.createFromJson('cadAutomaticoPER/modal/modalUploadArquivo', true);
        this.modalUploadArquivo.show();
    }

    public closeModalUploadArquivo() {
        this.modalUploadArquivo.hide();
        this.modalUploadArquivo?.destroy();
    }

    public formattedData(response: any) {
        const arraysFromBackend: string[][] = response.data;

        // Nomes dos elementos que você deseja
        const elementNames = ['CDLOCALUSO', 'NMFANTLUSO', 'NMRAZSOCLUSO', 'IDTPIJURLUSO', 'NRINSJURLUSO', 'NRINSESTLUSO', 'NRINSMUNILUSO', 'NMCONTLUSO', 'NMDEPTOLUSO', 'DSENDELUSO', 'NMBAIRLUSO', 'NRCEPLUSO', 'NMPAIS', 'SGESTADO', 'NMMUNICIPIO', 'NRTELELUSO', 'NRRAMALLUSO', 'NRFAXLUSO', 'DSEMAILCOMLU', 'CDLINPCLIE'];

        const formattedData = arraysFromBackend.slice(1).map((array) => {
            const obj: { [key: string]: any } = {};
            elementNames.forEach((elementName, i) => {
              obj[elementName] = array[i];
            });
            return obj;
        });

        return formattedData;
    }

    public async validaArquivoPersonalizado() {
        LoadingService.show();
        const grid = Metadata.getInstance<TekGrid>('gridExibicaoArquivo');
        const file = await Utilities.buildArrayToUpload('ARQUIVO');
        grid.datasource.data = [];
        (grid.datasource as MemoryDatasource).allData = [];
        if (file.length !== 0) {
            const response = await Http.post('/validaArquivoPersonalizado', {
                FILE: file,
            });
            const formattedData = this.formattedData(response);
            formattedData.forEach((element: any) => {
                const dados: any = {
                    CDLOCALUSO: element.CDLOCALUSO,
                    NMFANTLUSO: element.NMFANTLUSO,
                    NMRAZSOCLUSO: element.NMRAZSOCLUSO,
                    IDTPIJURLUSO: element.IDTPIJURLUSO,
                    NRINSJURLUSO: element.NRINSJURLUSO,
                    NRINSESTLUSO: element.NRINSESTLUSO,
                    NRINSMUNILUSO: element.NRINSMUNILUSO,
                    NMCONTLUSO: element.NMCONTLUSO,
                    NMDEPTOLUSO: element.NMDEPTOLUSO,
                    DSENDELUSO: element.DSENDELUSO,
                    NMBAIRLUSO: element.NMBAIRLUSO,
                    NRCEPLUSO: element.NRCEPLUSO,
                    NMPAIS: element.NMPAIS,
                    SGESTADO: element.SGESTADO,
                    NMMUNICIPIO: element.NMMUNICIPIO,
                    NRTELELUSO: element.NRTELELUSO,
                    NRRAMALLUSO: element.NRRAMALLUSO,
                    NRFAXLUSO: element.NRFAXLUSO,
                    DSEMAILCOMLU: element.DSEMAILCOMLU,
                    CDLINPCLIE: element.CDLINPCLIE,
               };
                grid.datasource.post(dados);
            });
        }
        grid.datasource.get();
        LoadingService.hide();
    }
}
